"""
Python mapping for the SafariServices framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Foundation
import objc
from SafariServices import _metadata
from SafariServices import _SafariServices

sys.modules["SafariServices"] = mod = objc.ObjCLazyModule(
    "SafariServices",
    "com.apple.SafariServices",
    objc.pathForFramework("/System/Library/Frameworks/SafariServices.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_SafariServices, Foundation),
)


del sys.modules["SafariServices._metadata"]



from PyObjCTools.TestSupport import TestCase, min_os_level

import SafariServices


class TestSFSafariTab(TestCase):
    @min_os_level("10.12")
    def testMethods(self):
        self.assertArgIsBlock(
            SafariServices.SFSafariTab.getActivePageWithCompletionHandler_, 0, b"v@"
        )
        self.assertArgIsBlock(
            SafariServices.SFSafariTab.getPagesWithCompletionHandler_, 0, b"v@"
        )
        self.assertArgIsBlock(
            SafariServices.SFSafariTab.activateWithCompletionHandler_, 0, b"v"
        )

    @min_os_level("10.14.4")
    def testMethods10_14(self):
        self.assertArgIsBlock(
            SafariServices.SFSafariTab.getContainingWindowWithCompletionHandler_,
            0,
            b"v",
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import SafariServices


class TestSFContentBlockerManager(TestCase):
    @min_os_level("10.12")
    def testMethods(self):
        self.assertArgIsBlock(
            SafariServices.SFContentBlockerManager.reloadContentBlockerWithIdentifier_completionHandler_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            SafariServices.SFContentBlockerManager.getStateOfContentBlockerWithIdentifier_completionHandler_,
            1,
            b"v@@",
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import SafariServices


class TestSFSafariToolbarItem(TestCase):
    @min_os_level("10.12")
    def testMethods(self):
        self.assertArgIsBOOL(
            SafariServices.SFSafariToolbarItem.setEnabled_withBadgeText_, 0
        )
        self.assertArgIsBOOL(SafariServices.SFSafariToolbarItem.setEnabled_, 0)



from PyObjCTools.TestSupport import TestCase, min_os_level

import SafariServices


class TestSFError(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(SafariServices.SFErrorCode)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(SafariServices.SFErrorNoExtensionFound, 1)
        self.assertEqual(SafariServices.SFErrorNoAttachmentFound, 2)
        self.assertEqual(SafariServices.SFErrorLoadingInterrupted, 3)



# This file is generated by objective.metadata
#
# Last update: Sun Feb 20 19:19:41 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$SFErrorDomain$SFExtensionMessageKey$"""
enums = """$SFErrorLoadingInterrupted@3$SFErrorNoAttachmentFound@2$SFErrorNoExtensionFound@1$SFSafariServicesVersion10_0@0$SFSafariServicesVersion10_1@1$SFSafariServicesVersion11_0@2$SFSafariServicesVersion12_0@3$SFSafariServicesVersion12_1@4$SFSafariServicesVersion13_0@5$"""
misc.update(
    {
        "SFErrorCode": NewType("SFErrorCode", int),
        "SFSafariServicesVersion": NewType("SFSafariServicesVersion", int),
    }
)
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSObject",
        b"additionalRequestHeadersForURL:completionHandler:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    },
                    "type": "@?",
                },
            },
        },
    )
    r(
        b"NSObject",
        b"contentBlockerWithIdentifier:blockedResourcesWithURLs:onPage:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"contextMenuItemSelectedWithCommand:inPage:userInfo:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"messageReceivedFromContainingAppWithName:userInfo:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"messageReceivedWithName:fromPage:userInfo:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"page:willNavigateToURL:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"popoverDidCloseInWindow:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"popoverViewController",
        {"required": False, "retval": {"type": b"@"}},
    )
    r(
        b"NSObject",
        b"popoverWillShowInWindow:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"toolbarItemClickedInWindow:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"validateContextMenuItemWithCommand:inPage:userInfo:validationHandler:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Z"},
                            2: {"type": b"@"},
                        },
                    },
                    "type": "@?",
                },
            },
        },
    )
    r(
        b"NSObject",
        b"validateToolbarItemInWindow:validationHandler:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Z"},
                            2: {"type": b"@"},
                        },
                    },
                    "type": "@?",
                },
            },
        },
    )
    r(
        b"SFContentBlockerManager",
        b"getStateOfContentBlockerWithIdentifier:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"SFContentBlockerManager",
        b"reloadContentBlockerWithIdentifier:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(b"SFContentBlockerState", b"isEnabled", {"retval": {"type": "Z"}})
    r(b"SFContentBlockerState", b"setEnabled:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"SFSafariApplication",
        b"dispatchMessageWithName:toExtensionWithIdentifier:userInfo:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSafariApplication",
        b"getActiveWindowWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSafariApplication",
        b"getAllWindowsWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSafariApplication",
        b"getHostApplicationWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSafariApplication",
        b"openWindowWithURL:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSafariApplication",
        b"showPreferencesForExtensionWithIdentifier:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSafariExtension",
        b"getBaseURIWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSafariExtensionManager",
        b"getStateOfSafariExtensionWithIdentifier:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"SFSafariExtensionState", b"isEnabled", {"retval": {"type": "Z"}})
    r(
        b"SFSafariPage",
        b"getContainingTabWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSafariPage",
        b"getPagePropertiesWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSafariPage",
        b"getScreenshotOfVisibleAreaWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(b"SFSafariPageProperties", b"isActive", {"retval": {"type": "Z"}})
    r(b"SFSafariPageProperties", b"usesPrivateBrowsing", {"retval": {"type": "Z"}})
    r(
        b"SFSafariTab",
        b"activateWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSafariTab",
        b"getActivePageWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSafariTab",
        b"getContainingWindowWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSafariTab",
        b"getPagesWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(b"SFSafariToolbarItem", b"setEnabled:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"SFSafariToolbarItem",
        b"setEnabled:withBadgeText:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"SFSafariWindow",
        b"getActiveTabWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSafariWindow",
        b"getAllTabsWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSafariWindow",
        b"getToolbarItemWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSafariWindow",
        b"openTabWithURL:makeActiveIfPossible:completionHandler:",
        {
            "arguments": {
                3: {"type": "Z"},
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                },
            }
        },
    )
    r(b"SFUniversalLink", b"isEnabled", {"retval": {"type": b"Z"}})
    r(b"SFUniversalLink", b"setEnabled:", {"arguments": {2: {"type": b"Z"}}})
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE
